@@ -225,7 +225,7 @@ void AddServiceDialog::accept()
     subProject->variables[varname] += (" " + fileName);
     QMap<QString, QString> replaceMap;
     replaceMap.insert(varname, subProject->variables[varname]);
-    AutoProjectTool::modifyMakefileam(subProject->path + "/Makefile.am", replaceMap);
+    AutoProjectTool::addToMakefileam(subProject->path + "/Makefile.am", replaceMap);
     
     QDialog::accept();
 }
