@@ -52,7 +52,7 @@
 #include "urlutil.h"
 
 InsideCheckListItem::InsideCheckListItem( QListView *parent, QMakeScopeItem *item, ProjectConfigurationDlg *config ) :
-        QCheckListItem( parent, item->relativePath().right( item->relativePath().length() - 1 ), QCheckListItem::CheckBox )
+        QCheckListItem( parent, item->relativePath().endsWith("/") ? item->relativePath().right( item->relativePath().length() - 1 ) : item->relativePath(), QCheckListItem::CheckBox )
 {
     prjItem = item;
     m_config = config;
@@ -1032,6 +1032,8 @@ void ProjectConfigurationDlg::updateIncludeControl()
     outsideinc_listview->clear();
 
     QStringList incList = myProjectItem->scope->variableValues( "INCLUDEPATH" );
+    QStringList intIncList = incList;
+    QMap<QString, InsideCheckListItem*> items;
     QPtrList <QMakeScopeItem> itemList = getAllProjects();
     QMakeScopeItem *item = itemList.first();
     while ( item )
@@ -1044,6 +1046,7 @@ void ProjectConfigurationDlg::updateIncludeControl()
             InsideCheckListItem *newItem = new InsideCheckListItem( insideinc_listview,
                                            insideinc_listview->lastItem(), item, this );
 
+            items[tmpInc] = newItem;
             if ( incList.findIndex( tmpInc ) != -1 )
             {
                 incList.remove( tmpInc );
@@ -1060,8 +1063,18 @@ void ProjectConfigurationDlg::updateIncludeControl()
     QStringList::Iterator it1 = incList.begin();
     for ( ;it1 != incList.end();++it1 )
     {
+        intIncList.remove(*it1);
         new QListViewItem( outsideinc_listview, outsideinc_listview->lastItem(), ( *it1 ) );
     }
+    for( QStringList::const_iterator it = intIncList.begin(); it != intIncList.end(); ++it )
+    {
+        insideinc_listview->insertItem( items[*it] );
+        items.remove(*it);
+    }
+    for( QMap<QString,InsideCheckListItem*>::ConstIterator it3 = items.begin(); it3 != items.end(); it3++ )
+    {
+        insideinc_listview->insertItem( it3.data() );
+    }
 }
 
 void ProjectConfigurationDlg::updateLibControls()
@@ -1078,6 +1091,8 @@ void ProjectConfigurationDlg::updateLibControls()
     //update librarys
     //temp strlist
     QStringList libList = myProjectItem->scope->variableValues( "LIBS" );
+    QStringList intLibList = libList;
+    QMap<QString, InsideCheckListItem*> items;
     QMakeScopeItem* item = itemList.first();
     while ( item )
     {
@@ -1087,11 +1102,13 @@ void ProjectConfigurationDlg::updateLibControls()
             {
                 // create lib string
                 QString tmpLib = item->getLibAddObject( myProjectItem->scope->projectDir() );
+
                 InsideCheckListItem * newItem = new InsideCheckListItem( insidelib_listview,
                                                 insidelib_listview->lastItem(), item, this );
+                insidelib_listview->takeItem( newItem );
+                items[tmpLib] = newItem;
                 QString tmpLibDir = item->getLibAddPath( myProjectItem->scope->projectDir() );
-                kdDebug(9024) << "lib path:" << tmpLib << endl;
-                kdDebug(9024) << "lib dir:" << tmpLibDir << endl;
+                kdDebug(9024) << "lib:" << tmpLib << " dir:" << tmpLibDir << "|" << libList << endl;
                 if ( libList.findIndex( "-L" + tmpLibDir ) != -1 )
                 {
                     libList.remove( "-L" + tmpLibDir );
@@ -1110,6 +1127,7 @@ void ProjectConfigurationDlg::updateLibControls()
     QStringList::Iterator it1 = libList.begin();
     for ( ;it1 != libList.end();++it1 )
     {
+        intLibList.remove( *it1 );
         if ( ( *it1 ).startsWith( "-L" ) )
             new QListViewItem( outsidelibdir_listview, outsidelibdir_listview->lastItem(), ( *it1 ).mid( 2 ) );
         else
@@ -1117,6 +1135,20 @@ void ProjectConfigurationDlg::updateLibControls()
             new QListViewItem( outsidelib_listview, outsidelib_listview->lastItem(), ( *it1 ) );
         }
     }
+
+    for( QStringList::const_iterator it = intLibList.begin(); it != intLibList.end(); ++it )
+    {
+        QString lib = *it;
+        if( !lib.startsWith( "-L" ) )
+        {
+            insidelib_listview->insertItem( items[lib] );
+            items.remove(lib);
+        }
+    }
+    for( QMap<QString,InsideCheckListItem*>::ConstIterator it3 = items.begin(); it3 != items.end(); it3++ )
+    {
+        insidelib_listview->insertItem( it3.data() );
+    }
 }
 
 void ProjectConfigurationDlg::updateDependenciesControl( )
@@ -1129,6 +1161,8 @@ void ProjectConfigurationDlg::updateDependenciesControl( )
     extDeps_view->clear();
 
     QStringList depsList = myProjectItem->scope->variableValues( "TARGETDEPS" );
+    QStringList intDepList = depsList;
+    QMap<QString,InsideCheckListItem*> items;
     QMakeScopeItem *item = itemList.first();
     while ( item )
     {
@@ -1145,6 +1179,7 @@ void ProjectConfigurationDlg::updateDependenciesControl( )
             else
                 tmpLib = item->getApplicationObject( myProjectItem->scope->projectDir() );
             InsideCheckListItem * newItem = new InsideCheckListItem( intDeps_view, intDeps_view->lastItem(), item, this );
+            items[tmpLib] = newItem;
             if ( depsList.findIndex( tmpLib ) != -1 )
             {
                 depsList.remove( tmpLib );
@@ -1158,11 +1193,23 @@ void ProjectConfigurationDlg::updateDependenciesControl( )
     //add all other prj in itemList unchecked
 
     extDeps_view->clear();
-    QStringList::Iterator it1 = depsList.begin();
-    for ( ;it1 != depsList.end();++it1 )
+    for ( QStringList::Iterator it1 = depsList.begin();it1 != depsList.end();++it1 )
     {
+        intDepList << *it1;
         new QListViewItem( extDeps_view, extDeps_view->lastItem(), ( *it1 ) );
     }
+
+
+    for( QStringList::const_iterator it = intDepList.begin(); it != intDepList.end(); ++it )
+    {
+        intDeps_view->insertItem( items[*it] );
+        items.remove(*it);
+    }
+
+    for( QMap<QString,InsideCheckListItem*>::ConstIterator it2 = items.begin(); it2 != items.end(); it2++ )
+    {
+        intDeps_view->insertItem( it2.data() );
+    }
 }
 
 
