@@ -65,7 +65,6 @@ public:
 public slots:
     //  virtual void           radioLibrarytoggled(bool);
     virtual void updateProjectConfiguration();
-    virtual void browseTargetPath();
 
     virtual void buildorderMoveUpClicked();
     virtual void buildorderMoveDownClicked();
@@ -102,7 +101,6 @@ public slots:
 
     virtual void addCustomValueClicked();
     virtual void removeCustomValueClicked();
-    virtual void editCustomValueClicked();
     virtual void upCustomValueClicked();
     virtual void downCustomValueClicked();
 
@@ -124,6 +122,7 @@ public slots:
     void updateBuildOrderControl();
     void updateDependenciesControl();
     virtual void activateApply(QListViewItem*);
+    virtual void customVarChanged();
 
 protected:
     QListView *prjList;
