@@ -1,6 +1,7 @@
+%{H_TEMPLATE}
 
-#ifndef _$APPNAMEUC$_H_
-#define _$APPNAMEUC$_H_
+#ifndef _%{APPNAMEUC}_H_
+#define _%{APPNAMEUC}_H_
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
@@ -10,22 +11,22 @@
 
 /**
  * @short Application Main Window
- * @author $AUTHOR$ <$EMAIL$>
- * @version $VERSION$
+ * @author %{AUTHOR} <%{EMAIL}>
+ * @version %{VERSION}
  */
-class $APPNAME$ : public KMainWindow
+class %{APPNAME} : public KMainWindow
 {
     Q_OBJECT
 public:
     /**
      * Default Constructor
      */
-    $APPNAME$();
+    %{APPNAME}();
 
     /**
      * Default Destructor
      */
-    virtual ~$APPNAME$();
+    virtual ~%{APPNAME}();
 };
 
-#endif // _$APPNAMEUC$_H_
+#endif // _%{APPNAMEUC}_H_
