@@ -1,5 +1,6 @@
+%{CPP_TEMPLATE}
 
-#include "$APPNAMELC$.h"
+#include "%{APPNAMELC}.h"
 #include <kapplication.h>
 #include <kaboutdata.h>
 #include <kcmdlineargs.h>
@@ -8,27 +9,27 @@
 static const char description[] =
     I18N_NOOP("A KDE KPart Application");
 
-static const char version[] = "$VERSION$";
+static const char version[] = "%{VERSION}";
 
 static KCmdLineOptions options[] =
 {
-//    { "+[URL]", I18N_NOOP( "Document to open." ), 0 },
+//    { "+[URL]", I18N_NOOP( "Document to open" ), 0 },
     KCmdLineLastOption
 };
 
 int main(int argc, char **argv)
 {
-    KAboutData about("$APPNAMELC$", I18N_NOOP("$APPNAME$"), version, description,
-                     KAboutData::License_$LICENSE$, "(C) $YEAR$ $AUTHOR$", 0, 0, "$EMAIL$");
-    about.addAuthor( "$AUTHOR$", 0, "$EMAIL$" );
+    KAboutData about("%{APPNAMELC}", I18N_NOOP("%{APPNAME}"), version, description,
+		     KAboutData::License_%{LICENSE}, "(C) %{YEAR} %{AUTHOR}", 0, 0, "%{EMAIL}");
+    about.addAuthor( "%{AUTHOR}", 0, "%{EMAIL}" );
     KCmdLineArgs::init(argc, argv, &about);
     KCmdLineArgs::addCmdLineOptions( options );
     KApplication app;
-    $APPNAME$ *mainWin = 0;
+    %{APPNAME} *mainWin = 0;
 
     if (app.isRestored())
     {
-        RESTORE($APPNAME$);
+        RESTORE(%{APPNAME});
     }
     else
     {
@@ -37,7 +38,7 @@ int main(int argc, char **argv)
 
         /// @todo do something with the command line args here
 
-        mainWin = new $APPNAME$();
+        mainWin = new %{APPNAME}();
         app.setMainWidget( mainWin );
         mainWin->show();
 
