@@ -1,6 +1,6 @@
 
-#ifndef _$APPNAMELC$_H_
-#define _$APPNAMELC$_H_
+#ifndef _%{APPNAMELC}_H_
+#define _%{APPNAMELC}_H_
 
 #include <qstring.h>
 #include <qcstring.h>
@@ -11,11 +11,11 @@
 
 class QCString;
 
-class kio_$APPNAMELC$Protocol : public KIO::SlaveBase
+class kio_%{APPNAMELC}Protocol : public KIO::SlaveBase
 {
 public:
-    kio_$APPNAMELC$Protocol(const QCString &pool_socket, const QCString &app_socket);
-    virtual ~kio_$APPNAMELC$Protocol();
+    kio_%{APPNAMELC}Protocol(const QCString &pool_socket, const QCString &app_socket);
+    virtual ~kio_%{APPNAMELC}Protocol();
     virtual void mimetype(const KURL& url);
     virtual void get(const KURL& url);
 };
