@@ -36,14 +36,28 @@
 #include <qfileinfo.h>
 #include <qtextstream.h>
 #include <list>
+#include <qdatastream.h>
+
+
+class BackgroundKDevDriver : public KDevDriver {
+public:
+	BackgroundKDevDriver( CppSupportPart* cppSupport, BackgroundParser* bp ) : KDevDriver( cppSupport, false ), m_backgroundParser(bp) {
+	}
+	virtual void fileParsed( ParsedFile& fileName );
+	virtual void addDependence( const QString& fileName, const Dependence& dep );
+private:
+	BackgroundParser* m_backgroundParser;
+};
 
 
 class KDevSourceProvider: public SourceProvider
 {
 public:
-	KDevSourceProvider( CppSupportPart* cppSupport )
+	//Deadlock is a mutex that is locked when KDevSourceProvider::contents(..) is used, and that should be unlocked before QApplication is locked(that way a deadlock where the thread that holds the QApplication-mutex and tries to lock the given mutex, while the thread that calls contents(..) and holds the given mutex and tries to lock the QApplication-mutex, cannot happen)
+	KDevSourceProvider( CppSupportPart* cppSupport, QMutex& deadlock )
 		: m_cppSupport( cppSupport ),
-		m_readFromDisk( false )
+		m_readFromDisk( false ),
+		m_deadlock(deadlock)
 	{}
 	
 	void setReadFromDisk( bool b )
@@ -61,9 +75,9 @@ public:
 		
 		if ( !m_readFromDisk )
 		{
+			m_deadlock.unlock();
 			// GET LOCK
-			kapp->lock ()
-				;
+			kapp->lock ();
 			
 			//kdDebug(9007) << "-------> kapp locked" << endl;
 			
@@ -84,9 +98,10 @@ public:
 				
 				break;
 			}
-			
+
 			// RELEASE LOCK
 			kapp->unlock();
+			m_deadlock.lock();
 			//kdDebug(9007) << "-------> kapp unlocked" << endl;
 		}
 		
@@ -107,6 +122,7 @@ public:
 	virtual bool isModified( const QString& fileName )
 	{
 		bool ret = false;
+		m_deadlock.unlock();
 		kapp->lock ();
 
 		KParts::ReadOnlyPart *part = m_cppSupport->partController()->partForURL( KURL(fileName) );
@@ -116,12 +132,14 @@ public:
 			ret = doc->isModified();
 
 		kapp->unlock();
+		m_deadlock.lock();
 		return ret;
 	}
 	
 private:
 	CppSupportPart* m_cppSupport;
 	bool m_readFromDisk;
+	QMutex& m_deadlock;
 private:
 	KDevSourceProvider( const KDevSourceProvider& source );
 	void operator = ( const KDevSourceProvider& source );
@@ -237,12 +255,14 @@ BackgroundParser::BackgroundParser( CppSupportPart* part, QWaitCondition* consum
 : m_consumed( consumed ), m_cppSupport( part ), m_close( false ), m_saveMemory( false )
 {
 	m_fileList = new SynchronizedFileList();
-	m_driver = new KDevDriver( m_cppSupport );
-	m_driver->setSourceProvider( new KDevSourceProvider( m_cppSupport ) );
+	m_driver = new BackgroundKDevDriver( m_cppSupport, this );
+	m_driver->setSourceProvider( new KDevSourceProvider( m_cppSupport,  m_mutex ) );
 	
 	QString conf_file_name = m_cppSupport->specialHeaderName();
+	m_mutex.lock();
 	if ( QFile::exists( conf_file_name ) )
-		m_driver->parseFile( conf_file_name, true );
+		m_driver->parseFile( conf_file_name, true, true, true );
+	m_mutex.unlock();
 	
 	//disabled for now m_driver->setResolveDependencesEnabled( true );
 }
@@ -327,8 +347,22 @@ void BackgroundParser::removeFile( const QString& fileName )
 		m_isEmpty.wakeAll();
 }
 
-Unit* BackgroundParser::parseFile( const QString& fileName, bool readFromDisk, bool lock )
+void BackgroundKDevDriver::addDependence( const QString& fileName, const Dependence& dep ) {
+	//give waiting threads a chance to perform their actions
+	m_backgroundParser->m_mutex.unlock();
+	m_backgroundParser->m_mutex.lock();
+	KDevDriver::addDependence( fileName, dep );
+}
+
+void BackgroundKDevDriver::fileParsed( ParsedFile& fileName ) {
+	m_backgroundParser->fileParsed( fileName );
+}
+
+void BackgroundParser::parseFile( const QString& fileName, bool readFromDisk, bool lock )
 {
+	if( lock )
+		m_mutex.lock();
+	m_readFromDisk = readFromDisk;
 	static_cast<KDevSourceProvider*>( m_driver->sourceProvider() ) ->setReadFromDisk( readFromDisk );
 	
 	m_driver->remove( fileName );
@@ -336,39 +370,62 @@ Unit* BackgroundParser::parseFile( const QString& fileName, bool readFromDisk, b
     if( !m_driver->isResolveDependencesEnabled() )
         m_driver->removeAllMacrosInFile( fileName );  // romove all macros defined by this
 	// translation unit.
-	ParsedFilePointer translationUnit = m_driver->takeTranslationUnit( fileName );
+    if ( lock )
+        m_mutex.unlock();
+}
+
+QValueList<Problem> cloneProblemList( const QValueList<Problem>& list ) {
+	QValueList<Problem> ret;
+	for( QValueList<Problem>::const_iterator it = list.begin(); it != list.end(); ++it ) {
+		ret << Problem( *it, true );
+	}
+	return ret;
+}
+
+void BackgroundParser::fileParsed( ParsedFile& file ) {
+
+	ParsedFilePointer translationUnitUnsafe = m_driver->takeTranslationUnit( file.fileName() );
+	//now file and translationUnitUnsafe are the same
+	ParsedFilePointer translationUnit;
+	//Since the lexer-cache keeps many QStrings like macro-names used in the background, everything must be copied here. The safest solution is just
+	//serializing and deserializing the whole thing(the serialization does not respect the AST, but that can be copied later because that's safe)
+	QMemArray<char> data;
+	{
+	  QDataStream stream( data, IO_WriteOnly );
+	  translationUnitUnsafe->write( stream );
+	}
+	{
+	  QDataStream stream( data, IO_ReadOnly );
+	  translationUnit = new ParsedFile( stream );
+	}
+
+	translationUnit->setTranslationUnit( translationUnitUnsafe->operator TranslationUnitAST *() ); //Copy the AST, doing that is thread-safe
+	translationUnitUnsafe->setTranslationUnit( 0 ); //Move the AST completely out of this thread's scope. Else it might crash on dual-core machines
+	file.setTranslationUnit(0); //just to be sure, set to zero on both
 	
 	Unit* unit = new Unit;
-	unit->fileName = fileName;
+	unit->fileName = file.fileName();
 	unit->translationUnit = translationUnit;
-	unit->problems = m_driver->problems( fileName );
+	unit->problems = cloneProblemList( m_driver->problems( file.fileName() ) );
 	
 	static_cast<KDevSourceProvider*>( m_driver->sourceProvider() ) ->setReadFromDisk( false );
 	
-	if ( lock )
-		m_mutex.lock();
-	
-	if ( m_unitDict.find( fileName ) != m_unitDict.end() )
+	if ( m_unitDict.find( file.fileName() ) != m_unitDict.end() )
 	{
-		Unit * u = m_unitDict[ fileName ];
-		m_unitDict.remove( fileName );
+		Unit * u = m_unitDict[ file.fileName() ];
+		m_unitDict.remove( file.fileName() );
 		delete( u );
 		u = 0;
 	}
 	
-	m_unitDict.insert( fileName, unit );
+	m_unitDict.insert( file.fileName(), unit );
 	
-	if ( lock )
-		m_mutex.unlock();
-	
-	KApplication::postEvent( m_cppSupport, new FileParsedEvent( fileName, unit->problems, readFromDisk ) );
+	KApplication::postEvent( m_cppSupport, new FileParsedEvent( file.fileName(), unit->problems, m_readFromDisk ) );
 	
 	m_currentFile = QString::null;
 	
-	if ( m_fileList->isEmpty() )
-		m_isEmpty.wakeAll();
-	
-	return unit;
+  if ( m_fileList->isEmpty() )
+		m_isEmpty.wakeAll();	
 }
 
 Unit* BackgroundParser::findUnit( const QString& fileName )
@@ -491,4 +548,5 @@ void BackgroundParser::saveMemory() {
 	m_canParse.wakeAll();
 }
 
+
 //kate: indent-mode csands; tab-width 4; space-indent off;
