@@ -58,9 +58,11 @@ CreateGetterSetterDialog::CreateGetterSetterDialog( CppSupportPart* part, ClassD
 	if ( ! config->prefixSet().isEmpty() )
 		setName[ 0 ] = setName[ 0 ].upper();
 
-	m_chkInlineGet->setChecked( config->isInlineGet() );
-	m_chkInlineSet->setChecked( config->isInlineSet() );
-
+	bool getIsChecked = config->isInlineGet();
+	bool setIsChecked = config->isInlineSet();
+	m_chkInlineGet->setChecked( getIsChecked );
+	m_chkInlineSet->setChecked( setIsChecked );
+	
 	m_edtGet->setText( config->prefixGet() + getName );
 	m_edtSet->setText( config->prefixSet() + setName );
 }
@@ -87,7 +89,7 @@ void CreateGetterSetterDialog::accept( )
 		}
 		else
 		{
-			QRegExp basicTypes( "(unsigned?\\s*(char|byte|short|int|long))|double|float|bool" );
+			QRegExp basicTypes( "((unsigned)?\\s*(char|byte|short|int|long))|double|float|bool" );
 			if ( basicTypes.exactMatch( m_var->type() ) )
 				parameterStr = m_var->type() + " " + config->parameterName();
 			else
