@@ -20,11 +20,9 @@
 #include <qstring.h>
 #include <qvaluevector.h>
 
-#include "dbgcommand.h"
 #include "mi/gdbmi.h"
 #include <qguardedptr.h>
 
-
 namespace GDBDebugger
 {
 
@@ -33,81 +31,40 @@ class Breakpoint;
 class VarItem;
 class ValueCallback;
 
-// sigh - namespace's don't work on some of the older compilers
-enum GDBCmd
-{
-  BLOCK_START     = '\32',
-  SRC_POSITION    = '\32',    // Hmmm, same value may not work for all compilers
-
-  ARGS            = 'a',
-  ALL_ARGS        = 'A',
-
-  BPLIST          = 'B',
-  SET_BREAKPT     = 'b',
-
-  DATAREQUEST     = 'D',
-  DISASSEMBLE     = 'd',
-
-  FRAME           = 'F',
-  FILE_START      = 'f',
-
-  WHATIS          = 'H',
-
-  INITIALISE      = 'I',
-  IDLE            = 'i',
-
-  BACKTRACE       = 'K',
-
-  LOCALS          = 'L',
-  LIBRARIES       = 'l',
-
-  MEMDUMP         = 'M',
-
-  WAIT            = '0',
-
-  TRACING_PRINTF  = 'P',
-
-  RUN             = 'R',
-  REGISTERS       = 'r',
-
-  PROGRAM_STOP    = 'S',
-  SHARED_CONT     = 's',
-
-  INFOTHREAD      = 'T',
-  SWITCHTHREAD    = 't',
-
-  USERCMD         = 'U',
-
-  SETVALUE        = 'V',
-
-  SETWATCH        = 'W',
-  UNSETWATCH      = 'w',
-
-  DETACH          = 'z'
- 
-};
-
-#define RUNCMD      (true)
-#define NOTRUNCMD   (false)
-#define INFOCMD     (true)
-#define NOTINFOCMD  (false)
-
 /**
  * @author John Birch
  */
 
-class GDBCommand : public DbgCommand
+class GDBCommand
 {
 public:
-    GDBCommand(const QString& command, bool isInfoCmd=true,
-               char prompt=WAIT);
+    GDBCommand(const QString& command);
 
     template<class Handler>
-    GDBCommand(const QString& command, // bool isInfoCmd,
+    GDBCommand(const QString& command,
                Handler* handler_this, 
                void (Handler::* handler_method)(const GDBMI::ResultRecord&),
                bool handlesError = false);
 
+    /* The command that should be sent to gdb.  
+       This method is virtual so the command can compute this
+       dynamically, possibly using results of the previous
+       commands.
+       If the empty string is returned, nothing is sent. */
+    virtual QString cmdToSend();
+
+    /* Returns the initial string that was specified in
+       ctor invocation. The actual command will be
+       determined by cmdToSend above and the return
+       value of this method is only used in various
+       diagnostic messages emitted before actually
+       sending the command. */
+    QString initialString() const;
+
+    /* Returns true if this is command entered by the user
+       and so should be always shown in the gdb output window. */
+    virtual bool isUserCommand() const;
+
     // If there's a handler for this command, invokes it and returns true.
     // Otherwise, returns false.
     virtual bool invokeHandler(const GDBMI::ResultRecord& r);
@@ -125,11 +82,20 @@ public:
 
     const QValueVector<QString>& allStreamOutput() const;
 
+    // True if this command run then target for
+    // unspecified period of time -- that is either 'run' or
+    // 'continue'. 
+    bool isRun() const;
+
+    void setRun(bool run);
+
 private:
+    QString command_;
     QGuardedPtr<QObject> handler_this;
     typedef void (QObject::* handler_t)(const GDBMI::ResultRecord&);
     handler_t handler_method;
     QValueVector<QString> lines;
+    bool run;
 
 protected: // FIXME: should be private, after I kill the first ctor
     // that is obsolete and no longer necessary.
@@ -137,6 +103,14 @@ protected: // FIXME: should be private, after I kill the first ctor
 
 };
 
+class UserCommand : public GDBCommand
+{
+public:
+    UserCommand(const QString& s);
+
+    bool isUserCommand() const;
+};
+
 /** This command is used to change some property of breakpoint.
     It holds a pointer to a Breakpoint object and will substitute
     breakpoint id into the command string.
@@ -196,7 +170,7 @@ public:
     template<class Handler>
     SentinelCommand(Handler* handler_this,
                     void (Handler::* handler_method)())
-    : GDBCommand("", NOTRUNCMD, NOTINFOCMD),
+    : GDBCommand(""),
       handler_this(handler_this),
       handler_method(static_cast<handler_method_t>(handler_method))
     {}
@@ -264,9 +238,10 @@ GDBCommand::GDBCommand(
     Handler* handler_this,
     void (Handler::* handler_method)(const GDBMI::ResultRecord&),
     bool handlesError)
-: DbgCommand(command, INFOCMD, WAIT),
+: command_(command),
   handler_this(handler_this), 
   handler_method(static_cast<handler_t>(handler_method)),
+  run(false),
   handlesError_(handlesError)
 {
 }
@@ -277,7 +252,7 @@ CliCommand::CliCommand(
     Handler* handler_this,
     void (Handler::* handler_method)(const QValueVector<QString>&),
     bool handlesError)
-: GDBCommand(command.latin1(), INFOCMD, WAIT),
+: GDBCommand(command.latin1()),
   cli_handler_this(handler_this), 
   cli_handler_method(static_cast<cli_handler_t>(handler_method))
 {
