@@ -225,6 +225,9 @@ public:
     int index() const;
     void setIndex( int index );
 
+    //returns the count of lines that wer skipped due to #ifdef's
+    int skippedLines() const;
+    
     void reset();
 
     const Token& tokenAt( int position ) const;
@@ -248,6 +251,13 @@ public:
     }
     
 private:
+    void setEndPtr( const QChar* c ) {
+      m_endPtr = c;
+      if( m_ptr <  m_endPtr )
+          m_currentChar = *m_ptr;
+      else
+          m_currentChar = QChar::null;
+    }
     const QChar currentChar() const;
     QChar peekChar( int n=1 ) const;
     int currentPosition() const;
@@ -315,7 +325,7 @@ private:
     __gnu_cxx::hash_map< HashedString, QPair<SkipType, QString> > m_words;
 
     
-    
+    int m_skippedLines;
     int m_currentLine;
     int m_currentColumn;
     bool m_skipWordsEnabled;
@@ -531,7 +541,6 @@ inline void Lexer::nextChar()
         m_currentChar = *m_ptr;
     else
         m_currentChar = QChar::null;
-
 }
 
 inline void Lexer::nextChar( int n )
@@ -851,6 +860,8 @@ inline void Lexer::insertCurrent( const QString& str ) {
     m_endPtr = offset( m_source.length() );
     if( m_ptr < m_endPtr )
       m_currentChar = *m_ptr;
+    else
+      m_currentChar = QChar::null;
 }
 
 #endif
