@@ -17,16 +17,14 @@
    Boston, MA 02111-1307, USA.
 */
 #include "KDevPartControllerIface.h"
-
-
 #include "kdevpartcontroller.h"
-
+#include "katedocumentmanagerinterface.h"
 
 KDevPartController::KDevPartController(QWidget *parent)
   : KParts::PartManager(parent)
 {
   new KDevPartControllerIface(this);
+  new KateDocumentManagerInterface(this);
 }
 
-
 #include "kdevpartcontroller.moc"
