@@ -32,6 +32,7 @@
 #include <qtoolbutton.h>
 #include <qtooltip.h>
 #include <qvalidator.h>
+#include <qtimer.h>
 #include <klistview.h>
 #include <kiconview.h>
 #include <kconfig.h>
@@ -79,6 +80,8 @@
 #include "filetemplate.h"
 #include "settings.h"
 
+#include "blockingkprocess.h"
+
 #include "profileengine.h"
 #include "profile.h"
 
@@ -91,7 +94,7 @@ AppWizardDialog::AppWizardDialog(AppWizardPart *part, QWidget *parent, const cha
     : AppWizardDialogBase(parent, name,true), m_pCurrentAppInfo(0),
 	m_profileSupport(new ProfileSupport(part))
 {
-	kdDebug( 9000 ) << "  ** AppWizardDialog::AppWizardDialog()" << endl;
+	kdDebug( 9010 ) << "  ** AppWizardDialog::AppWizardDialog()" << endl;
 
 	m_customOptions = 0L;
 	loadLicenses();
@@ -401,7 +404,7 @@ void AppWizardDialog::textChanged()
 {
 //    licenseChanged();
 
-	updateNextButtons();
+    updateNextButtons();
 }
 
 void AppWizardDialog::licenseChanged()
@@ -451,7 +454,7 @@ void AppWizardDialog::accept()
 {
     QFileInfo fi(finalLoc_label->text());
     // check /again/ whether the dir already exists; maybe users create it in the meantime
-    if (fi.exists()) {
+    if (fi.exists() ) {
         KMessageBox::sorry(this, i18n("The directory you have chosen as the location for "
                                       "the project already exists."));
         showPage(generalPage);
@@ -460,10 +463,19 @@ void AppWizardDialog::accept()
         return;
     }
 
+    if( !QFileInfo(dest_edit->url()).isWritable()  ){
+        KMessageBox::sorry(this, i18n("The directory you have chosen as the location for "
+                                      "the project is not writeable."));
+        showPage(generalPage);
+        appname_edit->setFocus();
+        projectLocationChanged();
+        return;
+    }
+
 	QString source = kdevRoot( m_pCurrentAppInfo->templateName );
 
 	// Unpack template archive to temp dir, and get the name
-
+	kdDebug(9010) << "Unpacking archive to temp dir" << endl;
 	KTempDir archDir;
 	archDir.setAutoDelete(true);
 	KTar templateArchive( source + "/" + m_pCurrentAppInfo->sourceArchive, "application/x-gzip" );
@@ -480,6 +492,7 @@ void AppWizardDialog::accept()
 	}
 	templateArchive.close();
 
+	kdDebug(9010) << "build macro map" << endl;
 	// Build KMacroExpander map
 	//m_customOptions->dataForm()->fillPropertyMap(&m_pCurrentAppInfo->subMap);
 	PropertyLib::PropertyList::Iterator idx = m_pCurrentAppInfo->propValues->begin();
@@ -516,6 +529,8 @@ void AppWizardDialog::accept()
 	QStringList cleanUpSubstMap;
 	cleanUpSubstMap << "src" << "I18N" << "kdevelop";
 
+
+	kdDebug(9010) << "add template files" << endl;
 	// Add template files to the fileList
 	installDir templateDir;
 	templateDir.dir = "%{dest}/templates";
@@ -585,6 +600,7 @@ void AppWizardDialog::accept()
 	for( ; fileIt != m_pCurrentAppInfo->fileList.end(); ++fileIt)
 	{
 		(*fileIt).source = KMacroExpander::expandMacros((*fileIt).source , m_pCurrentAppInfo->subMap);
+		kdDebug(9010) << "Updating file dest: " << (*fileIt).dest << " with " << KMacroExpander::expandMacros((*fileIt).dest , m_pCurrentAppInfo->subMap) << endl;
 		(*fileIt).dest = KMacroExpander::expandMacros((*fileIt).dest , m_pCurrentAppInfo->subMap);
 	}
 
@@ -601,6 +617,14 @@ void AppWizardDialog::accept()
 		(*dirIt).dir = KMacroExpander::expandMacros((*dirIt).dir , m_pCurrentAppInfo->subMap);
 	}
 
+    if( !m_pCurrentAppInfo->finishCmd.isEmpty() )
+    {
+        m_pCurrentAppInfo->finishCmd = KMacroExpander::expandMacros(
+                m_pCurrentAppInfo->finishCmd, m_pCurrentAppInfo->subMap );
+        m_pCurrentAppInfo->finishCmdDir = KMacroExpander::expandMacros(
+                m_pCurrentAppInfo->finishCmdDir, m_pCurrentAppInfo->subMap );
+    }
+
 	QMap<QString,QString>::Iterator mapIt( m_pCurrentAppInfo->subMap.begin() );
 	for( ; mapIt != m_pCurrentAppInfo->subMap.end(); ++mapIt )
 	{
@@ -615,7 +639,7 @@ void AppWizardDialog::accept()
 	dirIt = m_pCurrentAppInfo->dirList.begin();
 	for( ; dirIt != m_pCurrentAppInfo->dirList.end(); ++dirIt)
 	{
-		kdDebug( 9000 ) << "Process dir " << (*dirIt).dir  << endl;
+		kdDebug( 9010 ) << "Process dir " << (*dirIt).dir  << endl;
 		if( m_pCurrentAppInfo->subMap[(*dirIt).option] != "false" )
 		{
 			if( ! KIO::NetAccess::mkdir( (*dirIt).dir, this ) )
@@ -679,11 +703,22 @@ void AppWizardDialog::accept()
 		m_pCurrentAppInfo->subMap.remove( *cleanIt );
 	}
 
-        if  (!m_pCurrentAppInfo->finishCmd.isEmpty())
-           if (KDevAppFrontend *appFrontend = m_part->extension<KDevAppFrontend>("KDevelop/AppFrontend"))
-              appFrontend->startAppCommand(KMacroExpander::expandMacros(m_pCurrentAppInfo->finishCmdDir, m_pCurrentAppInfo->subMap), KMacroExpander::expandMacros(m_pCurrentAppInfo->finishCmd, m_pCurrentAppInfo->subMap), false);
+      if  (!m_pCurrentAppInfo->finishCmd.isEmpty())
+      {
+        BlockingKProcess proc;
+        proc.setWorkingDirectory( m_pCurrentAppInfo->finishCmdDir );
+        proc.setUseShell( true );
+        proc << "cd" << m_pCurrentAppInfo->finishCmdDir << "&&";
+        proc << m_pCurrentAppInfo->finishCmd;
+        kdDebug(9010) << "Executing:" << proc.args() << endl;
+        proc.start( KProcess::NotifyOnExit );
+        if( !proc.isRunning() && !proc.normalExit() )
+        {
+            kdDebug(9010) << "Couldn't execute: " << proc.args() << endl;
+        }
+      }
+
 
-	openAfterGeneration();
 
 	int id = m_vcsForm->stack->id(m_vcsForm->stack->visibleWidget());
 	if (id)
@@ -700,11 +735,13 @@ void AppWizardDialog::accept()
 	else
 		kdDebug(9010) << "vcs integrator wasn't selected" << endl;
 
+	openAfterGeneration();
 	QWizard::accept();
 }
 
 bool AppWizardDialog::copyFile( const installFile& file )
 {
+	kdDebug(9010) << "Copying file" << file.dest << endl;
 	return
 		copyFile( file.source, file.dest, file.isXML, file.process );
 }
@@ -902,21 +939,21 @@ void AppWizardDialog::projectLocationChanged()
 {
   // Jakob Simon-Gaarde: Got tired of the anoying bug with the appname/location confussion.
   // This version insures WYSIWYG and checks pathvalidity
-  finalLoc_label->setText(dest_edit->url() + (dest_edit->url().right(1)=="/" ? "":"/") + appname_edit->text().lower());
+  finalLoc_label->setText(dest_edit->url() + (dest_edit->url().right(1)=="/" ? "":"/") + appname_edit->text());
   QDir qd(dest_edit->url());
-  QFileInfo fi(dest_edit->url() + "/" + appname_edit->text().lower());
+  QFileInfo fi(dest_edit->url() + "/" + appname_edit->text());
   if (!qd.exists() || appname_edit->displayText().isEmpty()||fi.exists())
   {
     if (!fi.exists() || appname_edit->displayText().isEmpty()) {
       finalLoc_label->setText(finalLoc_label->text() + i18n("invalid location", " (invalid)"));
     } else {
-      finalLoc_label->setText(finalLoc_label->text() + i18n(" (dir/file already exist)"));
+      finalLoc_label->setText(finalLoc_label->text() + i18n(" (dir/file already exists)"));
     }
     m_pathIsValid=false;
   } else {
     m_pathIsValid=true;
   }
-	updateNextButtons();
+  updateNextButtons();
 }
 
 
@@ -1029,7 +1066,10 @@ void AppWizardDialog::openAfterGeneration()
 	// open the new project
 	m_part->core()->openProject( projectFile );
 
-	// open files to open
+	// calculate the list of files to open after generation and use
+	// timer to queue opening (so that files will not be opened before the project
+	// which is also queued by ProjectManager )
+	KURL::List urlsToOpen;
 	QStringList::Iterator it = m_pCurrentAppInfo->openFilesAfterGeneration.begin();
 	for( ; it != m_pCurrentAppInfo->openFilesAfterGeneration.end(); ++it )
 	{
@@ -1037,15 +1077,19 @@ void AppWizardDialog::openAfterGeneration()
 		if ( !fileName.isNull() )
 		{
 			fileName = KMacroExpander::expandMacros(fileName, m_pCurrentAppInfo->subMap);
-			m_part->partController()->editDocument( fileName );
+			urlsToOpen.append(KURL::fromPathOrURL(fileName));
 		}
 	}
+	m_part->openFilesAfterGeneration(urlsToOpen);
 }
 
 void AppWizardDialog::pageChanged()
 {
 	kdDebug(9010) << "AppWizardDialog::pageChanged()" << endl;
 	projectLocationChanged();
+	if (currentPage() == m_lastPage)
+		finishButton()->setDefault(true);
+
 
 	//it is possible that project name was changed - we need to update all vcs integrator dialogs
 	for (QMap<int, VCSDialog*>::iterator it = m_integratorDialogs.begin();
@@ -1249,7 +1293,7 @@ void AppWizardDialog::loadLicenses()
 		KDevLicense* lic = new KDevLicense( licName, licPath );
 		m_licenses.insert( licName, lic );
 	}
-	// kdDebug(9000) << "======================== Done loadLicenses" << endl;
+	// kdDebug(9010) << "======================== Done loadLicenses" << endl;
 }
 
 void AppWizardDialog::showTemplates(bool all)
