@@ -31,6 +31,9 @@
 #include <kio/jobclasses.h>
 #include <kio/job.h>
 
+#include <kdevmainwindow.h>
+
+#include "diffpart.h"
 #include "diffwidget.h"
 
 // yup, magic value for the popupmenu-id
@@ -86,6 +89,9 @@ QPopupMenu* KDiffTextEdit::createPopupMenu( const QPoint& p )
   popup->setItemChecked( POPUP_BASE - 1, _highlight );
   popup->insertSeparator( 3 );
 
+  popup->insertSeparator();
+  popup->insertItem( i18n("Hide view"), parent(), SLOT(hideView()) );
+
   return popup;
 }
 
@@ -174,8 +180,8 @@ void KDiffTextEdit::popupActivated( int id )
   emit externalPartRequested( extParts[ id ] );
 }
 
-DiffWidget::DiffWidget( QWidget *parent, const char *name, WFlags f ):
-    QWidget( parent, name, f ), tempFile( 0 )
+DiffWidget::DiffWidget( DiffPart * part, QWidget *parent, const char *name, WFlags f ):
+    QWidget( parent, name, f ), m_part( part ), tempFile( 0 )
 {
   job = 0;
   extPart = 0;
@@ -192,6 +198,7 @@ DiffWidget::DiffWidget( QWidget *parent, const char *name, WFlags f ):
 
 DiffWidget::~DiffWidget()
 {
+    m_part = 0;
     delete tempFile;
 }
 
@@ -313,7 +320,11 @@ void DiffWidget::contextMenuEvent( QContextMenuEvent* /* e */ )
   QPopupMenu* popup = new QPopupMenu( this );
 
   if ( !te->isVisible() )
+  {
     popup->insertItem( i18n("Display &Raw Output"), this, SLOT(showTextEdit()) );
+    popup->insertSeparator();
+    popup->insertItem( i18n("Hide view"), this, SLOT(hideView()) );
+  }
 
   popup->exec( QCursor::pos() );
   delete popup;
@@ -329,4 +340,9 @@ void DiffWidget::showTextEdit()
   setExtPartVisible( false );
 }
 
+void DiffWidget::hideView()
+{
+  m_part->mainWindow()->setViewAvailable( this, false );
+}
+
 #include "diffwidget.moc"
