@@ -146,7 +146,7 @@ KFileTreeViewItem* VCSFileTreeBranchItem::createTreeViewItem( KFileTreeViewItem*
 
     FileTreeWidget *lv = static_cast<filetreeview::FileTreeViewItem*>( parent )->listView();
     const KURL fileURL = fileItem->url();
-    bool isDirectory = lv->projectFiles().contains( fileURL.path() ) > 0;
+    const bool isDirectory = lv->isInProject( fileURL.path() );
 
     VCSFileTreeViewItem *newItem = new VCSFileTreeViewItem( parent, fileItem, this, isDirectory );
 
