@@ -163,7 +163,7 @@ MakeWidget::MakeWidget(MakeViewPart *part)
 	updateSettingsFromConfig();
 
 	setTextFormat( Qt::RichText );
-	
+
 	if ( m_bLineWrapping )
 		setWordWrap(WidgetWidth);
 	else
@@ -176,13 +176,19 @@ MakeWidget::MakeWidget(MakeViewPart *part)
 	mimeSourceFactory()->setImage("warning", QImage((const char**)warning_xpm));
 	mimeSourceFactory()->setImage("message", QImage((const char**)message_xpm));
 
+        dirstack.setAutoDelete(true);
+
 	childproc = new KProcess(this);
 	procLineMaker = new ProcessLineMaker( childproc );
 
-	connect( procLineMaker, SIGNAL(receivedStdoutLine(const QString&)),
-	         this, SLOT(insertStdoutLine(const QString&) ));
-	connect( procLineMaker, SIGNAL(receivedStderrLine(const QString&)),
-	         this, SLOT(insertStderrLine(const QString&) ));
+	connect( procLineMaker, SIGNAL(receivedStdoutLine(const QCString&)),
+	         this, SLOT(insertStdoutLine(const QCString&) ));
+	connect( procLineMaker, SIGNAL(receivedStderrLine(const QCString&)),
+                 this, SLOT(insertStderrLine(const QCString&) ));
+        connect( procLineMaker, SIGNAL(receivedPartialStdoutLine(const QCString&)),
+                 this, SLOT(storePartialStdoutLine(const QCString&) ));
+        connect( procLineMaker, SIGNAL(receivedPartialStderrLine(const QCString&)),
+                 this, SLOT(storePartialStderrLine(const QCString&) ));
 
 	connect( childproc, SIGNAL(processExited(KProcess*)),
 	         this, SLOT(slotProcessExited(KProcess*) )) ;
@@ -207,8 +213,9 @@ MakeWidget::MakeWidget(MakeViewPart *part)
 	connect( horizontalScrollBar(), SIGNAL(sliderReleased()),
 	         this, SLOT(horizScrollingOff()) );
 
-	connect( m_part->partController(), SIGNAL(loadedFile(const KURL&)),
-	         this, SLOT(slotDocumentOpened(const KURL&)) );
+// this slot doesn't exist anymore
+// 	connect( m_part->partController(), SIGNAL(loadedFile(const KURL&)),
+// 	         this, SLOT(slotDocumentOpened(const KURL&)) );
 }
 
 MakeWidget::~MakeWidget()
@@ -314,8 +321,8 @@ void MakeWidget::copy()
 	for(int i = parafrom; i<=parato; i++)
 	   selection += text(i) + "\n";
 
-   	   
-	if(m_compilerOutputLevel == eShort || 
+
+	if(m_compilerOutputLevel == eShort ||
 	   m_compilerOutputLevel == eVeryShort )
 	{
 	   QRegExp regexp("<.*>");
@@ -327,14 +334,14 @@ void MakeWidget::copy()
 	  selection.remove(0, indexfrom);
 	  int removeend = text(parato).length() - indexto;
 
-	  selection.remove((selection.length()-1) -  removeend, removeend);	   
-	}		
-	   
+	  selection.remove((selection.length()-1) -  removeend, removeend);
+	}
+
 	selection.replace("&lt;","<");
 	selection.replace("&gt;",">");
 	selection.replace("&quot;","\"");
-	selection.replace("&amp;","&");	
-	   
+	selection.replace("&amp;","&");
+
 	kapp->clipboard()->setText(selection, QClipboard::Clipboard);
 }
 
@@ -442,6 +449,17 @@ void MakeWidget::specialCheck( const QString& file, QString& fName ) const
             kdDebug(9004) << "MakeWidget::specialCheck thinks that url is: " << url.url()
                 << " origin: " << file << endl;
             fName = url.url();
+            return;
+        }
+    }
+    // Ok the "worst case", lets see if we can find a file in the project that has the same name
+    // obviously this will pick always the wrong file when you've got the same filename multiple times.
+    QStringList files = m_part->project()->allFiles();
+    for( QStringList::iterator it = files.begin() ; it != files.end(); ++it)
+    {
+        if( (*it).contains( file ) )
+        {
+            fName = URLUtil::canonicalPath( m_part->project()->projectDirectory() + "/" + *it );
         }
     }
 }
@@ -504,36 +522,43 @@ void MakeWidget::searchItem(int parag)
 	{
 		// open the file
 		kdDebug(9004) << "Opening file: " << guessFileName(item->fileName, parag) << endl;
-		if (item->m_cursor) {
-			uint line, col;
-			item->m_cursor->position(&line, &col);
-			kdDebug() << "Cursor new position: " << col << endl;
-			m_part->partController()->editDocument(KURL( guessFileName(item->fileName, parag) ), line, col);
-		} else {
-			m_part->partController()->editDocument(KURL( guessFileName(item->fileName, parag) ), item->lineNum);
-		}
+		m_part->partController()->editDocument(KURL( guessFileName(item->fileName, parag) ), item->lineNum);
 		m_part->mainWindow()->statusBar()->message( item->m_error, 10000 );
         m_lastErrorSelected = parag;
 	}
 }
 
-void MakeWidget::insertStdoutLine( const QString& line )
+void MakeWidget::insertStdoutLine( const QCString& line )
 {
-	if ( !appendToLastLine( line ) )
-		m_directoryStatusFilter.processLine( line );
+    QString sline;
+    bool forceCLocale = KConfigGroup( kapp->config(), "MakeOutputWidget" ).readBoolEntry( "ForceCLocale", true );
+    if( forceCLocale )
+        sline = QString::fromAscii( stdoutbuf+line );
+    else
+        sline = QString::fromLocal8Bit( stdoutbuf+line );
+    stdoutbuf.truncate(0);
+
+    if ( !appendToLastLine( sline ) )
+        m_directoryStatusFilter.processLine( sline );
 }
 
-void MakeWidget::insertStderrLine( const QString& line )
+void MakeWidget::insertStderrLine( const QCString& line )
 {
-	if ( !appendToLastLine( line ) )
-        {
-            kdDebug() << "inserting stderr line: " << line << endl;
-		m_errorFilter.processLine( line );
-  }
+    QString sline;
+    bool forceCLocale = KConfigGroup( kapp->config(), "MakeOutputWidget" ).readBoolEntry( "ForceCLocale", true );
+    if( forceCLocale ) {
+        sline = QString( stderrbuf+line );
+    }
+    else
+        sline = QString::fromLocal8Bit( stderrbuf+line );
+    stderrbuf.truncate(0);
+    if ( !appendToLastLine( line ) )
+        m_errorFilter.processLine( line );
 }
 
 void MakeWidget::slotProcessExited(KProcess *)
 {
+	procLineMaker->flush();
 	if (childproc->normalExit())
 	{
 		if (childproc->exitStatus())
@@ -550,7 +575,7 @@ void MakeWidget::slotProcessExited(KProcess *)
 
 	MakeItem* item = new ExitStatusItem( childproc->normalExit(), childproc->exitStatus() );
 	insertItem( item );
-  displayPendingItem();
+        displayPendingItem();
 
 	m_part->mainWindow()->statusBar()->message( QString("%1: %2").arg(currentCommand).arg(item->m_text), 3000);
 	m_part->core()->running(m_part, false);
@@ -605,7 +630,7 @@ void MakeWidget::displayPendingItem()
   // We call displayPendingItem once in insertItem
   // and the appends are handled directly in
   // appendToLastLine
-  if (!m_items.empty() 
+  if (!m_items.empty()
       && m_items.last() == m_pendingItem) return;
 
   m_items.push_back(m_pendingItem);
@@ -641,10 +666,6 @@ bool MakeWidget::appendToLastLine( const QString& text )
 
 void MakeWidget::insertItem( MakeItem* new_item )
 {
-	ErrorItem* e = dynamic_cast<ErrorItem*>(new_item);
-	if (e)
-		createCursor(e, 0L);
-
   displayPendingItem();
   m_pendingItem = new_item;
 
@@ -659,69 +680,6 @@ void MakeWidget::insertItem( MakeItem* new_item )
   }
 }
 
-void MakeWidget::slotDocumentOpened( const KURL & filename )
-{
-	KParts::Part* part = m_part->partController()->partForURL(filename);
-	KTextEditor::Document* doc = dynamic_cast<KTextEditor::Document*>(part);
-
-	if (!doc) {
-		kdWarning() << k_funcinfo << "Couldn't find the document that was just opened." << endl;
-		return;
-	}
-
-	connect(part, SIGNAL(destroyed(QObject*)), this, SLOT(slotDocumentClosed(QObject*)) );
-
-	for (QValueVector<MakeItem*>::iterator it = m_items.begin(); it != m_items.end(); ++it) {
-		ErrorItem* e = dynamic_cast<ErrorItem*>(*it);
-
-		if (!e || e->m_cursor) continue;
-
-		if (filename.path().endsWith(e->fileName))
-			createCursor(e, doc);
-	}
-}
-
-void MakeWidget::createCursor(ErrorItem* e, KTextEditor::Document* doc)
-{
-	// Disabled for now - comment out to test. You need an up-to-date cvs head katepart to avoid mem leaks
-    return;
-
-	// try to get a KTextEditor::Cursor, so that we can retain position in
-	// a document even when it is edited
-	if (!doc)
-		doc = dynamic_cast<KTextEditor::Document*>(m_part->partController()->partForURL(KURL( guessFileName(e->fileName, m_paragraphs + 1 ))));
-
-	if (doc) {
-		KTextEditor::EditInterface* edit = dynamic_cast<KTextEditor::EditInterface*>(doc);
-		KTextEditor::CursorInterface* cursor = dynamic_cast<KTextEditor::CursorInterface*>(doc);
-		if (cursor) {
-			e->m_cursor = cursor->createCursor();
-			uint col = 0;
-			static QRegExp startOfText("[\\S]");
-			if (edit) {
-				int newcol = edit->textLine(e->lineNum).find(startOfText);
-				if (newcol != -1) col = uint(newcol);
-			}
-			e->m_cursor->setPosition(e->lineNum, col);
-			e->m_doc = doc;
-		}
-	}
-}
-
-void MakeWidget::slotDocumentClosed(QObject* doc)
-{
-	KTextEditor::Document* document = static_cast<KTextEditor::Document*>(doc);
-
-	for (QValueVector<MakeItem*>::iterator it = m_items.begin(); it != m_items.end(); ++it) {
-		ErrorItem* e = dynamic_cast<ErrorItem*>(*it);
-
-		if (!e || e->m_doc != document) continue;
-
-		e->m_cursor = 0L;
-		e->m_doc = 0L;
-	}
-}
-
 bool MakeWidget::brightBg()
 {
 	int h,s,v;
@@ -867,4 +825,14 @@ bool MakeWidget::scanErrorBackward( int parag )
 	return false;
 }
 
+void MakeWidget::storePartialStderrLine(const QCString & line)
+{
+    stderrbuf += line;
+}
+
+void MakeWidget::storePartialStdoutLine(const QCString & line)
+{
+    stderrbuf += line;
+}
+
 #include "makewidget.moc"
